==> resource-aware-commons-1.0.0-20140417.201619-39-sources.jar: org/gcube/rest/commons/resourceawareservice/resources/StatefulResource.java <==
package org.gcube.rest.commons.resourceawareservice.resources;

import java.io.Serializable;
import java.util.Calendar;

import javax.xml.bind.JAXBException;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.rest.commons.helpers.JSONConverter;
import org.gcube.rest.commons.helpers.XMLConverter;
import org.gcube.rest.commons.resourceawareservice.resources.exceptions.StatefulResourceException;

@XmlRootElement
public abstract class StatefulResource implements Serializable {
	private static final long serialVersionUID = 1L;
	
	private String resourceID;
	
	private Calendar created;
	
	private Calendar lastUpdated;

	public final String getResourceID() {
		return this.resourceID;
	}

	public void setResourceID(String resourceID) {
		this.resourceID = resourceID;
	}

	@XmlElement
	public Calendar getCreated() {
		return created;
	}

	public void setCreated(Calendar created) {
		this.created = created;
	}

	@XmlElement
	public Calendar getLastUpdated() {
		return lastUpdated;
	}

	public void setLastUpdated(Calendar lastUpdated) {
		this.lastUpdated = lastUpdated;
	}
	
	
	public String toJSON(){
		return JSONConverter.convertToJSON(this);
	}
	
	public String toJSON(Boolean pretty){
		return JSONConverter.convertToJSON(this, pretty);
	}
	
	public String toXML() throws JAXBException {
		return XMLConverter.convertToXML(this);
	}
	
	public String toXML(Boolean pretty) throws JAXBException {
		return XMLConverter.convertToXML(this, pretty);
	}

	abstract public void onLoad() throws StatefulResourceException;
	abstract public void onClose() throws StatefulResourceException;
	abstract public void onDestroy() throws StatefulResourceException;
}

==> resource-aware-commons-2.0.0-20180923.050818-1961-sources.jar: org/gcube/rest/commons/resourceawareservice/resources/StatefulResource.java <==
package org.gcube.rest.commons.resourceawareservice.resources;

import java.io.Serializable;
import java.util.Calendar;

import javax.xml.bind.JAXBException;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.rest.commons.helpers.JSONConverter;
import org.gcube.rest.commons.helpers.XMLConverter;
import org.gcube.rest.commons.resourceawareservice.resources.exceptions.StatefulResourceException;

@XmlRootElement
public abstract class StatefulResource extends GeneralResource implements Serializable {
	private static final long serialVersionUID = 1L;
	
	private Calendar created;
	
	private Calendar lastUpdated;

	@XmlElement
	public Calendar getCreated() {
		return created;
	}

	public void setCreated(Calendar created) {
		this.created = created;
	}

	@XmlElement
	public Calendar getLastUpdated() {
		return lastUpdated;
	}

	public void setLastUpdated(Calendar lastUpdated) {
		this.lastUpdated = lastUpdated;
	}
	
	
	public String toJSON(){
		return JSONConverter.convertToJSON(this);
	}
	
	public String toJSON(Boolean pretty){
		return JSONConverter.convertToJSON(this, pretty);
	}
	
	public String toXML() throws JAXBException {
		return XMLConverter.convertToXML(this);
	}
	
	public String toXML(Boolean pretty) throws JAXBException {
		return XMLConverter.convertToXML(this, pretty);
	}

	abstract public void onLoad() throws StatefulResourceException;
	abstract public void onClose() throws StatefulResourceException;
	abstract public void onDestroy() throws StatefulResourceException;
}
